#!/usr/bin/apt-get script
-- This script will install NVIDIA driver
-- Author: Sergey V Turchin <zerg@altlinux.org>

function os.getexecout(cmd)
  local f = assert(io.popen(cmd, 'r'))
  local s = assert(f:read('*a'))
  f:close()
  s = string.gsub(s, '^%s+', '')
  s = string.gsub(s, '%s+$', '')
  s = string.gsub(s, '[\n\r]+', ' ')
  return s
end

function str_remove_disttag(str_ver)
    local ver_list = {}
    for a in str_ver:gmatch("[^:]+") do
        table.insert(ver_list,a)
    end
    if #ver_list > 2 then
        str_ver = ver_list[1] .. ":" .. ver_list[2]
    end
    return str_ver
end

if script_slot == "Scripts::AptGet::Help::Command" then
    print(_("   install-nvidia - Install NVIDIA driver"))
    return
end

if command_args and command_args[1] ~= "install-nvidia" then return end
command_consume = 1

kernel_name = os.getexecout("uname -r")
kernel_nameversion = os.getexecout("rpmquery-strictdep -f /boot/vmlinuz-" .. kernel_name)
if kernel_nameversion == "" then
    apterror(_("Package not found for your current kernel ") .. kernel_name .. " .")
    return
end

pkg_kernel_prov_name = kernel_nameversion:gsub("%s+=.*", "")
pkg_kernel_prov_verstr = kernel_nameversion:gsub(".*=%s+", "")
if pkg_kernel_prov_name == "" or pkg_kernel_prov_verstr == "" then
    apterror(_("Unable to parse kernel package version."))
    return
end
-- Find kernel-modules-nvidia package
nvidia_pkg = nil
nvidia_ver = nil
for i, pkg in ipairs(pkglist()) do
    if string.find(pkgname(pkg), "kernel-modules-nvidia-", 0, true) == 1 then
	-- print("Package " .. pkgname(pkg))
	ver = pkgvercand(pkg)
	if ver == nil then
	    ver = pkgvercur(pkg)
	end
	if ver ~= nil then
	    for i, dep in ipairs(verdeplist(ver)) do
		if dep.name == pkg_kernel_prov_name and verstrcmp(dep.verstr,pkg_kernel_prov_verstr) == 0 then
		    if( nvidia_pkg == nil or nvidia_ver == nil or verstrcmp(verstr(ver),verstr(nvidia_ver)) > 0 ) then
			-- print("Package " .. pkgname(pkg) .. " require " .. dep.name .. "#" .. dep.verstr)
			nvidia_pkg = pkg
			nvidia_ver = ver
			break
		    end
		end
	    end
	end
    end
end
if nvidia_pkg ~= nil then
    -- print("Try to install package " .. pkgname(nvidia_pkg) .. " .")
    markinstall(nvidia_pkg)
end

-- Find 32-bit packages for 64-bit system
if nvidia_pkg and os.getexecout("uname -m") == "x86_64" then
    if pkgfind("i586-libX11.32bit") then
	ver = pkgvercand(nvidia_pkg)
	if ver == nil then
	    ver = pkgvercur(nvidia_pkg)
	end
	for i, dep in ipairs(verdeplist(ver)) do
	    if string.find(dep.name, "nvidia_glx_", 0, true) == 1 then
		-- print(" require " .. dep.name)
		nvidia32_pkg = pkgfind("i586-" .. dep.name .. ".32bit")
		if nvidia32_pkg ~= nil then
		    markinstall(nvidia32_pkg)
		end
	    end
	end
    end
end

if nvidia_pkg == nil then
    print(_("NVIDIA driver not found for your kernel ") .. kernel_name .. " .")
    print(_("Be sure you did `apt-get update` and `update-kernel`."))
end
